@@ -1,5 +1,3 @@
-from core_main_app.utils.databases.mongoengine_database import Database
-
 SECRET_KEY = "fake-key"
 
 INSTALLED_APPS = [
@@ -15,6 +13,10 @@ INSTALLED_APPS = [
     "captcha",
     "django_celery_beat",
     # Local apps
+    "core_main_app",
+    "core_website_app",
+    "core_parser_app",
+    "core_curate_app",
     "core_user_registration_app",
     "tests",
 ]
@@ -65,13 +67,8 @@ ROOT_URLCONF = "tests.urls"
 DEFAULT_AUTO_FIELD = "django.db.models.AutoField"
 PASSWORD_HASHERS = ("django.contrib.auth.hashers.UnsaltedMD5PasswordHasher",)
 
-MOCK_DATABASE_NAME = "db_mock"
-MOCK_DATABASE_HOST = "mongomock://localhost"
-
 DATA_SORTING_FIELDS = ["+title"]
 
 CUSTOM_NAME = "Curator"
 ENABLE_SAML2_SSO_AUTH = False
-
-database = Database(MOCK_DATABASE_HOST, MOCK_DATABASE_NAME)
-database.connect()
+CELERYBEAT_SCHEDULER = "django_celery_beat.schedulers:DatabaseScheduler"
